==> qore-1.4.0.tar.bz2: qore-1.4.0/docs/modules/Util/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Util Module Reference", "index.html", [
    [ "Util Module", "index.html", [
      [ "Util Module Introduction", "index.html#utilintro", null ],
      [ "Release Notes", "index.html#utilrelnotes", [
        [ "Util 1.7", "index.html#util_1_7", null ],
        [ "Util 1.6.2", "index.html#util_1_6_2", null ],
        [ "Util 1.6.1", "index.html#util_1_6_1", null ],
        [ "Util 1.6", "index.html#util_1_6", null ],
        [ "Util 1.5.1", "index.html#util_1_5_1", null ],
        [ "Util 1.5", "index.html#util_1_5", null ],
        [ "Util 1.4.1", "index.html#util_1_4_1", null ],
        [ "Util 1.4", "index.html#util_1_4", null ],
        [ "Util 1.3", "index.html#util_1_3", null ],
        [ "Util 1.2", "index.html#util_1_2", null ],
        [ "Util 1.1", "index.html#util_1_1", null ],
        [ "Util 1.0", "index.html#util_1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.5.0.tar.bz2: qore-1.5.0/docs/modules/Util/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Util Module Reference", "index.html", [
    [ "Util Module", "index.html", [
      [ "Util Module Introduction", "index.html#utilintro", null ],
      [ "Release Notes", "index.html#utilrelnotes", [
        [ "Util 1.7", "index.html#util_1_7", null ],
        [ "Util 1.6.2", "index.html#util_1_6_2", null ],
        [ "Util 1.6.1", "index.html#util_1_6_1", null ],
        [ "Util 1.6", "index.html#util_1_6", null ],
        [ "Util 1.5.1", "index.html#util_1_5_1", null ],
        [ "Util 1.5", "index.html#util_1_5", null ],
        [ "Util 1.4.1", "index.html#util_1_4_1", null ],
        [ "Util 1.4", "index.html#util_1_4", null ],
        [ "Util 1.3", "index.html#util_1_3", null ],
        [ "Util 1.2", "index.html#util_1_2", null ],
        [ "Util 1.1", "index.html#util_1_1", null ],
        [ "Util 1.0", "index.html#util_1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
